@@ -4,14 +4,21 @@ use warnings;
 use Web::Scraper;
 use URI;
 
-my $url = 'http://developers.softbankmobile.co.jp/dp/tech_svc/web/ip.php';
+my $url = 'http://creation.mb.softbank.jp/web/web_ip.html';
 
 sub scrape {
     scraper {
-        process '//td[@bgcolor="#eeeeee"]/font[@size="2" and @class="j10"]', 'cidr[]', ['TEXT', sub {
-                        m{^([0-9.]+)(/[0-9]+)};
-                        +{ ip => $1, subnetmask => $2 };
-                    }];
+        process q{//div[@class='contents']/table/tr[7]/td/table/tr/td/table/tr},
+          'cidr[]', [
+            'TEXT',
+            sub {
+                s/\s//g
+            },
+            sub {
+                m{^([0-9.]+)(/[0-9]+)};
+                +{ ip => $1, subnetmask => $2 };
+              }
+          ];
     }->scrape(URI->new($url))->{cidr};
 }
 
